import { useContextKey } from '@kevisual/use-config/context';
import { BucketItemStat } from 'minio';
import { Model, DataTypes } from 'sequelize';

export type FileSyncModelType = {};
export class FileSyncModel extends Model {
  declare id: string;
  declare name: string;
  declare hash: string;

  declare stat: BucketItemStat;
  declare data: any;

  declare createdAt: Date;
  declare updatedAt: Date;
  declare checkedAt: Date;

  get user() {
    const name = this.name || '';
    const _u = name.split('/')[0];
    return _u || '';
  }
  async updateStat(stat: BucketItemStat) {
    const currentStat = this.stat || {};
    const equal = JSON.stringify(currentStat) === JSON.stringify(stat);
    if (!equal) {
      await this.update({
        hash: stat.etag || '',
        stat,
        checkedAt: new Date(),
      });
      return {
        type: 'updateStat',
      };
    }
    const checkedAt = this.checkedAt;
    // 对比当前时间，如果超过了15天，更新为当前时间
    const fifteenDays = 15 * 24 * 60 * 60 * 1000; // 15 days in milliseconds
    if (Date.now() - new Date(checkedAt).getTime() > fifteenDays) {
      await this.update({ checkedAt: new Date() });
      return {
        type: 'updateCheckedAt',
      };
    }
    return {
      type: 'noChange',
    };
  }
}

export const initFileSyncModel = async () => {
  const sequelize = await useContextKey('sequelize');
  FileSyncModel.init(
    {
      id: {
        type: DataTypes.UUID,
        primaryKey: true,
        defaultValue: DataTypes.UUIDV4,
        comment: 'id',
      },
      name: {
        type: DataTypes.STRING,
        allowNull: true,
      },
      hash: {
        type: DataTypes.STRING,
        allowNull: true,
      },
      stat: {
        type: DataTypes.JSONB,
        allowNull: true,
        defaultValue: {},
      },
      data: {
        type: DataTypes.JSONB,
        allowNull: true,
        defaultValue: {},
      },
      checkedAt: {
        type: DataTypes.DATE,
        allowNull: true,
        defaultValue: DataTypes.NOW,
        comment: 'Last checked time',
      },
    },
    {
      sequelize,
      tableName: 'file_sync',
      indexes: [
        {
          name: 'file_sync_name_idx',
          fields: ['name'],
        },
      ],
    },
  );
  await FileSyncModel.sync({ alter: true, logging: false }).catch((err) => {
    console.error('Error syncing FileSyncModel:', err);
  });
  return FileSyncModel;
};

initFileSyncModel();
