import { minioClient, bucketName } from '@/modules/minio.ts';
import utils from 'node:util';
import { app } from '@/app.ts';
// import { NotificationRecord } from 'minio';
type NotificationRecord = {
  eventName: string;
  s3: {
    bucket: {
      name: string;
      arn: string;
    };
    object: {
      key: string;
      size: number;
      eTag: string;
      contentType: string;
      userMetadata: Record<string, string>;
      sequencer?: string;
    };
  };
};

// 监听事件
export const listen = async () => {
  const res = minioClient.listenBucketNotification(bucketName, '', '', [
    's3:ObjectCreated:*', // 监听所有对象创建事件
    // delete
    's3:ObjectRemoved:*',
  ]);
  res.on('notification', (event: NotificationRecord) => {
    // console.log(event);
    const eventName = event.eventName;
    const ev = eventName.split(':').slice(0, 2).join(':');
    let data = {
      key: event.s3.object.key,
      type: '',
    };
    if (data.key.startsWith('private/')) {
      return;
    }
    switch (ev) {
      case 's3:ObjectCreated':
        data.type = 'create';
        break;
      case 's3:ObjectRemoved':
        data.type = 'delete';
        break;
      default:
        console.log('Unknown event:', eventName);
        break;
    }
    // console.log('obj', utils.inspect(event.s3.object, false, null, true));
    if (data.type) {
      app.call({
        path: 'file-listener',
        key: 'sync-file',
        payload: {
          data: data,
        },
      });
    }
  });
  // const res = await minioClient.getBucketNotification('mark');
  // console.log(res);
};
