import { Sequelize } from 'sequelize';
import { config } from './config.ts';
import { logger } from './logger.ts';

export type PostgresConfig = {
  postgres: {
    username: string;
    password: string;
    host: string;
    port: number;
    database: string;
  };
};
if (!config.POSTGRES_PASSWORD || !config.POSTGRES_USER) {
  logger.error('postgres config is required password and user');
  logger.error('config', config);
  process.exit(1);
}
const postgresConfig = {
  username: config.POSTGRES_USER,
  password: config.POSTGRES_PASSWORD,
  host: config.POSTGRES_HOST || 'localhost',
  port: parseInt(config.POSTGRES_PORT || '5432'),
  database: config.POSTGRES_DB || 'postgres',
};
// connect to db
export const sequelize = new Sequelize({
  dialect: 'postgres',
  ...postgresConfig,
  // logging: false,
});

sequelize
  .authenticate({ logging: false })
  .then(() => {
    logger.info('Database connected');
  })
  .catch((err) => {
    logger.error('Database connection failed', { err, config: postgresConfig });
    process.exit(1);
  });
